==> haskell-http-streams-0.8.6.1-116-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-H3dkIIdmucNKfFNIDOQtqD
key: http-streams-0.8.6.1-H3dkIIdmucNKfFNIDOQtqD
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: 53d8e8f61dd236674e561a39659e605c
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-H3dkIIdmucNKfFNIDOQtqD
depends:
    HsOpenSSL-0.11.4.16-7RfyZJwAYaPLvukdLJguyi
    aeson-1.4.3.0-3wMMTmWfRNQF9dYXhjYZYB
    attoparsec-0.13.2.2-WGDHRY8MTWGzoRjbN9EJO base-4.12.0.0
    base64-bytestring-1.0.0.2-11TO9fSEmuqDlOPx6IouNl
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk directory-1.3.3.0
    http-common-0.8.2.0-8ExcoiPu4eW5O5JHmwoyJH
    io-streams-1.5.1.0-Jr5Q18rgJkN1NXr3uJxXfl mtl-2.2.2
    network-2.8.0.0-xbHtkcSHJTFxVBp7aTame
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    openssl-streams-1.2.2.0-H0zNyBbXVlw6NEapryKAI1 text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-9wTHYlaSuHyGA5dBBp2WV8
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-streams-0.8.6.1-119-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-KqBKlxUuXKooVpbxgtHgW
key: http-streams-0.8.6.1-KqBKlxUuXKooVpbxgtHgW
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: 7decfc867fc7ade49ec7fde9359784fa
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-KqBKlxUuXKooVpbxgtHgW
depends:
    HsOpenSSL-0.11.4.16-286z3fleDVvC6QIierEbG1
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq
    attoparsec-0.13.2.2-IYmscZi60PM1VHlw2sOR1C base-4.12.0.0
    base64-bytestring-1.0.0.2-Bm9gqw70QXoBbkNHszCarm
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk directory-1.3.3.0
    http-common-0.8.2.0-9lSqEtwEInD8IWm2CUQC66
    io-streams-1.5.1.0-ARrp9xtkjAMDJvKX3hLohn mtl-2.2.2
    network-2.8.0.0-EWiez0ajBalJ2cORFP4yEt
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    openssl-streams-1.2.2.0-95JBiEtM5n814ll69zLdk3 text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
